const app = getApp<IAppOption>();

Page({
  data: {
    background: 'transparent',

    list: [],
    pagination: {
      page: 1,
      pages: 1,
      count: 1,
    },
    recommendList: [],
    recommendPagination: {
      page: 1,
      pages: 1,
      count: 0,
    },

    cateList: [] as any,
    CateId: '',
    CateSecondId: '',
    cateSecondList: [] as any,

    scrollIntoView: '',
  },
  onLoad(options) {
    this.setData({
      CateId: options.id || '',
    });
    app.waitLogin().then(() => {
      this.getCateList();
      this.cateCallback(this.data.CateId, this.data.CateSecondId);
    });
  },
  getCateList() {
    wx.ajax({
      method: 'GET',
      url: '?r=shizhong/book/cate-list',
      data: {},
    }).then((res) => {
      this.setData({
        cateList: res,
      });
      if (this.data.CateId) {
        this.setData({
          cateSecondList: res.find((item: any) => item.Id === this.data.CateId)?.Children || [],
          scrollIntoView: `nav-item${this.data.CateId}`,
        });
      }
    });
  },
  handleCate(e) {
    const { index } = e.currentTarget.dataset;
    if (typeof index === 'number') {
      this.setData({
        CateId: this.data.cateList[index].Id,
        CateSecondId: '',
        cateSecondList: this.data.cateList[index].Children,
      });
    } else {
      this.setData({ CateId: '', CateSecondId: '', cateSecondList: [] });
    }
    this.cateCallback(this.data.CateId, this.data.CateSecondId);
  },
  handleSecondCate(e) {
    const { index } = e.currentTarget.dataset;
    if (typeof index === 'number') {
      this.setData({
        CateSecondId: this.data.cateSecondList[index].Id,
      });
    } else {
      this.setData({ CateSecondId: '' });
    }
    this.cateCallback(this.data.CateId, this.data.CateSecondId);
  },
  cateCallback(CateId, CateSecondId) {
    this.setData({
      list: [],
      pagination: {
        page: 1,
        pages: 1,
        count: 1,
      },
      recommendList: [],
      recommendPagination: {
        page: 1,
        pages: 1,
        count: this.data.CateSecondId ? 1 : 0,
      },
    });
    this.getList(1, CateId, CateSecondId);
    if (CateId && CateSecondId) {
      this.getRecommendList(1, CateId, CateSecondId);
    }
  },
  getList(newPage = 1, CateId, CateSecondId) {
    wx.ajax({
      method: 'GET',
      url: `?r=shizhong/book/list`,
      data: {
        page: newPage,
        CateId,
        CateSecondId,
      },
    }).then((res) => {
      const list = res.page === 1 ? res.list : [...this.data.list, ...res.list];
      this.setData({
        list,
        pagination: {
          page: res.page,
          pages: res.pages,
          count: res.count,
        },
      });
    });
  },
  getRecommendList(newPage = 1, CateId, CateSecondId) {
    wx.ajax({
      method: 'GET',
      url: '?r=shizhong/book/recommend-list',
      data: {
        CateId,
        CateSecondId,
        page: newPage,
      },
    }).then((res) => {
      const recommendList = res.page === 1 ? res.list : [...this.data.recommendList, ...res.list];
      this.setData({
        recommendList,
        recommendPagination: {
          page: res.page,
          pages: res.pages,
          count: res.count,
        },
      });
    });
  },
  onReachBottom() {
    const { page, pages } = this.data.pagination;
    const { page: rPage, pages: rPages } = this.data.recommendPagination;
    if (pages > page && this.data.list.length) {
      this.getList(page + 1, this.data.CateId, this.data.CateSecondId);
    } else if (rPages > rPage && this.data.recommendList.length && this.data.CateId && this.data.CateSecondId) {
      this.getRecommendList(rPage + 1, this.data.CateId, this.data.CateSecondId);
    }
  },
  handleCollect(e) {
    const { index, list } = e.currentTarget.dataset;
    const { Id } = this.data[list][index];
    app.waitLogin(false, true).then(() => {
      wx.ajax({
        method: 'POST',
        url: '?r=shizhong/book/collect',
        data: { BookId: Id },
      }).then(() => {
        wx.showToast({
          title: '您已收藏这本书，可在我的页查看',
          icon: 'none',
        });
        this.setData({
          [`${list}[${index}].IsCollect`]: '1',
        });
      });
    });
  },
  handleUnCollect(e) {
    const { index, list } = e.currentTarget.dataset;
    const { Id } = this.data[list][index];
    app.waitLogin(false, true).then(() => {
      wx.ajax({
        method: 'POST',
        url: '?r=shizhong/book/cancel-collect',
        data: { BookId: Id },
      }).then(() => {
        wx.showToast({
          title: '取消收藏',
          icon: 'none',
        });
        this.setData({
          [`${list}[${index}].IsCollect`]: '0',
        });
      });
    });
  },
  handleDetail(e) {
    const { id } = e.currentTarget.dataset;
    const backPath = `/pages/article/index?id=${id}`;
    app.waitLogin(false, true, backPath).then(() => {
      wx.navigateTo({
        url: backPath,
      });
    });
  },
  handleBack() {
    wx.navigateBack();
  },
});

export {};
